pino.py
=======

> **Json natural logger for python** inspired by [pino.js](https://github.com/pinojs/pino) :evergreen_tree:

[![PyPI](https://img.shields.io/pypi/v/pino.svg)](https://pypi.org/project/pino/)
[![Supported Python Versions](https://img.shields.io/pypi/pyversions/pino.svg)](https://pypi.python.org/pypi/pino)
[![Build Status](https://travis-ci.com/CoorpAcademy/pino.py.svg?branch=master)](https://travis-ci.com/CoorpAcademy/pino.py)

> In building port of [pinojs](https://github.com/pinojs/pino) logging library to python :snake:

:warning: This is a in building prototype, it's API is subject to change.
A CHANGELOG will be introduced once it's stable enough and publicized.
Use it at you own risk, but feel free to reach with an issue.
